@@ -59,16 +59,17 @@ class DictToXMLTestCase(unittest.TestCase):
         self.assertEqual(_strip(unparse(parse(xml))),
                          '<a><d></d>abcefg</a>')
 
-    def test_preprocessor(self):
-        obj = {'a': OrderedDict((('b:int', [1, 2]), ('b', 'c')))}
-        def p(key, value):
-            try:
-                key, _ = key.split(':')
-            except ValueError:
-                pass
-            return key, value
-        self.assertEqual(_strip(unparse(obj, preprocessor=p)),
-                         '<a><b>1</b><b>2</b><b>c</b></a>')
+    if hasattr(collections, 'OrderedDict'):
+        def test_preprocessor(self):
+            obj = {'a': OrderedDict((('b:int', [1, 2]), ('b', 'c')))}
+            def p(key, value):
+                try:
+                    key, _ = key.split(':')
+                except ValueError:
+                    pass
+                return key, value
+            self.assertEqual(_strip(unparse(obj, preprocessor=p)),
+                             '<a><b>1</b><b>2</b><b>c</b></a>')
 
     def test_preprocessor_skipkey(self):
         obj = {'a': {'b': 1, 'c': 2}}
